@section('title', 'VisiMisi')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Visi Misi {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    Menjadi Institusi Penyelenggra Pendidikan Tinggi Teknologi Terbaik di Sumatera yang berlandaskan Islam, Iman dan Ihksan pada tahun 2041
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                <li>
                Melaksanakan Tri Dharma Perguruan Tinggi yang kompatibel dengan kebutuhan masyarakat dan perkembangan teknologi. 
                </li>
                <li>
                    Menciptakan iklim akademis yang kreatif, inovatif, efektif dan efisien bagi pendidikan tinggi teknologi yang selaras dengan dinamika kebutuhan masyarakat dan perkembangan teknologi.
                </li>
                 <li>
                    Menerapkan dan mengembangkan kurikulum pendidikan teknologi berkelanjutan yang koherendan kompatibel sesuai dengan kebutuhan masyarakat dan kemajuan teknologi baru terbarukan.
                </li>                 
                <li>
                    Meningkatkan kualitas Sumber daya Manusia sebagai tenaga terampil dan Ahli di bidang Teknologi yang kompatibel berdasarkan dinamika kebutuhan masyarakat dan perkembangan teknologi.
                </li>                 
                <li>
                Melengkapi sarana dan prasarana bagi kebutuhan proses pembelajaran teknologi yang selaras dengan dinamika kebutuhan masyarakat dan perkembangan teknologi.
                </li>                 
                <li>
                Melakukan kerjasama dengan berbagai pihak (pemerintah, dunia usaha, industri dan pihak swasta lainnya) baik di dalam maupun di luar negeri bagi kebutuhan pendidikan teknologi yang berkelanjutan.
                </li>                
                <li>
                Proaktif dalam inovasi yang solusif dalam permasalahan yang dinamis di masyarakat yang berkaitan dengan kebutuhan teknologi.
                </li>
                
               
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}
                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
