<div class="my-3">
    <a href="{{ $url }}"
        class="text-accent hover:text-white w-[180px] duration-200 md:w-[240px] border border-[2px] border-accent hover:border hover:border-[#F9F9F9]/15 hover:rounded-full hover:border-[2px] font-Anek hover:bg-accent hover:border-accent font-bold rounded-full text-[14px] px-4 md:px-5 py-2.5 text-center me-2 mb-4 md:mb-2">
        {{ $slot }}
    </a>
</div>