<?php $__env->startSection('title', 'Program Studi'); ?>


<?php $__env->startSection('content'); ?>
<div class="min-h-screen h-auto flex flex-col items-center md:flex-row justify-center md:justify-start py-8 md:py-[100px] px-4 md:px-[200px] bg-right-top bg-cover bg-no-repeat"
    style="background-image: url('<?php echo e(asset('./images/background/bg-1.png')); ?>');">
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[90%] mt-4 md:mt-0" data-aos="fade-up">

        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => 'BIAYA & PROGRAM STUDI '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','subtextColor' => '#0a2682','title' => ' ','titleColor' => '#0a2682']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>

        <?php $__currentLoopData = $biayas->groupBy('kategori'); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $kategori => $biayasByKategori): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
            <h1 class="text-3xl md:text-4xl font-bold text-primary font-poppins mb-4 text-center md:text-start w-full">
                <?php echo e($kategori); ?>

            </h1>

            <div class="swiper mySwiper w-full">
                <div class="swiper-wrapper space-x-[10px] pb-[20px] md:ps-[20px]">
                    <?php $__currentLoopData = $biayasByKategori; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $biaya): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        
                        <div class="swiper-slide bg-white shadow-lg rounded-lg p-5 w-full sm:w-[280px] md:w-[320px] flex flex-col space-y-4">
                            <h3 class="text-lg font-semibold text-primary font-poppins"><?php echo e($biaya->jurusan); ?></h3>
                            <div class="text-sm font-dmsans text-gray-600 space-y-1">
                                <p>Biaya Registrasi Pendaftaran: 
                                    <span class="text-primary font-medium">
                                        <!--BIAYA PENDAFtARAN-->
                                        <?php if($kategori == 'Blended Learning'): ?>
                                            <?php echo e($settings['reguler'] ?? 'tidak tersedia'); ?>

                                        <?php elseif($kategori == 'Reguler'): ?>
                                            <?php echo e($settings['reguler'] ?? 'tidak tersedia'); ?>                                       
                                        <?php else: ?>
                                            Tidak tersedia
                                        <?php endif; ?>
                                    </span>
                                </p>
                                <p>Biaya Awal: <span class="text-primary font-medium">Rp. <?php echo e(number_format($biaya->biaya_awal, 0, ',', '.')); ?></span></p>
                                <p>Biaya Bulanan: <span class="text-primary font-medium">Rp. <?php echo e(number_format($biaya->biaya_spp, 0, ',', '.')); ?></span></p>
                            </div>
                            <div class="flex justify-between items-center mt-3 gap-3">
                                <a href="/pendaftaran" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center text-white">Daftar Sekarang</a>
                                <a href="/brosur" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all w-full text-center text-white">Informasi</a>
                            </div>
                        </div>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </div><br>
                <div class="swiper-pagination mt-2"></div>
            </div>
        <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>

        <div data-aos="fade-up" class="flex md:items-center justify-center items-center flex-col w-full pt-5">
            <div class="w-full h-[1px] bg-blue-900 my-4"></div>
            <p class="text-center md:text-start mb-5 text-[14px] font-dmsans md:text-[14px] lg:text-[16px]">
                Bersama <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>, kami hadir untuk membangun masa depan gemilang melalui program studi terbaik, pengajaran berkualitas, dan fasilitas modern yang dirancang untuk mendukung langkah suksesmu.
            </p>
            <a href="/pendaftaran" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all text-center text-white">PENDAFTARAN ONLINE</a>
        </div>
    </div>
</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Biru-Kuning/resources/views/Frontend/biayakuliah.blade.php ENDPATH**/ ?>