.swiper {
    height: 100%;
}

.swiper-slide {
    text-align: center;
    font-size: 18px;
    display: flex;
    justify-content: center;
    align-items: center;
}

.swiper2 {
    width: 100%;
    padding-top: 50px;
    padding-bottom: 50px;
}

.swiper-slide2{
    background-position: center;
    background-size: cover;
    width: 300px;
    height: 300px;
}


