<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Kurikulum extends Model
{
    protected $table = 'kurikulum';
    protected $primaryKey = 'id_kurikulum';
    protected $fillable = ['jurusan', 'file'];
    public $timestamps = false;
}
