<?php

namespace Faker\Provider\ru_RU;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'черный', 'темно-бордовый', 'зеленый', 'темно-синий', 'оливковый',
        'фиолетовый', 'зеленовато-голубой', 'синий', 'серебро',
        'серый', 'желтый', 'фуксия', 'цвет морской волны', 'белый',
    ];

    protected static $allColorNames = [
        'Военно-воздушный синий', 'Синяя Элис', 'Ализариновый красный', 'Миндаль Крайола', 'Амарантовый', 'Янтарный',
        'Американская роза', 'Аметистовый', 'Матовый белый', 'Античный белый', 'Яблочно-зеленый', 'Спаржа',
        'Цвет морской волны', 'Аквамариновый', 'Армейский зелёный', 'Мышьяковый', 'Лазурный', 'Бежевый',
        'Бистр', 'Горькая радость', 'Чёрный', 'Белокурый', 'Синий', 'Вода пляжа Бонди', 'Латунный', 'Ярко-зелёный',
        'Сиена жжёная', 'Хаки', 'Кардинал', 'Морковный', 'Лазурный', 'Каштановый', 'Шоколадный', 'Коричный',
        'Кобальт синий', 'Кремовый', 'Циан', 'Индиго', 'Фуксия', 'Кирпичный', 'Льняной', 'Золотой', 'Зелёный',
        'Индиго', 'Нефритовый', 'Сиреневый', 'Охра', 'Панг', 'Берлинская лазурь', 'Красновато-коричневый',
        'Сангрия', 'Сепия', 'Болотный', 'Тициановый', 'Чертополох', 'Глициния', 'Вино', 'Циннвальдит',
    ];
}
