<?php

namespace Faker\Provider\uk_UA;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'чорний', 'темно-бордовий', 'зелений', 'темно-синій', 'оливковий',
        'фіолетовий', 'помаранчевий', 'синій', 'червоний',
        'сірий', 'жовтий', 'блакитний', 'морська хвиля', 'білий',
    ];

    protected static $allColorNames = [
        'Бурштиновий', 'Абрикосовий', 'Зелений армійський', 'Спаржевий', 'Амарантовий', 'Янтарний',
        'Ніжно-блакитний', 'Аметистовий', 'Матовий білий', 'Античний білий', 'Смарагдовий', 'Спаржа',
        'Захисний синій', 'Жовто-зелений', 'Сіра спаржа', 'Індиго', 'Лавандний', 'Хакі', 'Нефритовий',
        'Лайм', 'Гірчичний', 'Чорний', 'Малахітовий', 'Синій', 'Вода пляжа Бонді', 'Латуний', 'Пурпурний',
        'Орхідея', 'Блідо-брунатний', 'Зелена сосна', 'Гарбуз', 'Лазурний', 'Каштановий', 'Шоколадний', 'Умбра',
        'Кобальтовий', 'Кремовий', 'Циан', 'Іржавий', 'Фуксия', 'Шафрановий', 'Лляний', 'Золотий', 'Зелений',
        'Лимонний', 'Ліловий', 'Перський синій', 'Охра', 'Панг', 'Сливовий', 'Фіолетово-червоний', 'Сірий',
        'Багряний', 'Срібний', 'Болотний', 'Пшеничний', 'Пастельно-зелений', 'Умбра', 'Лососевий', 'Синя сталь',
    ];
}
