<?php

namespace Faker\Provider\hy_AM;

class Color extends \Faker\Provider\Color
{
    protected static $safeColorNames = [
        'սև', 'դեղին', 'սպիտակ', 'մոխրագույն', 'կարմիր',
        'կապույտ', 'երկնագույն', 'կանաչ', 'կապտականաչ',
        'մանուշակագույն', 'շագանակագույն',
    ];
}
