<!DOCTYPE html>
<html>

<head>
    <title>Konfirmasi Pendaftaran</title>
</head>

<body>
    <p><b>Kepada Yth Calon Mahasiswa di Tempat,</b></p>
    <p>Terima kasih Anda telah melakukan Pendaftaran Online di situs kami dengan data berikut:</p>
    <p>Nomor Pendaftaran: <b><?php echo e($data['no_daftar']); ?></b><br>
        Perguruan Tinggi: <b><?php echo e($data['kampus']); ?></b><br>
        Jurusan: <?php echo e($data['jurusan']); ?><br>
        Informasi Biaya Pendaftaran:
        <ul>
            <?php if(isset($data['jenjang_tersedia']) && count($data['jenjang_tersedia']) > 0): ?>
                <?php $__currentLoopData = $data['jenjang_tersedia']; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $jenjang => $biaya): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <li><strong><?php echo e($jenjang); ?>:</strong> Rp. <?php echo e($biaya); ?>,-</li>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            <?php else: ?>
                <li><strong>S1:</strong>150.000,-</li>
            <?php endif; ?>
        </ul>
        Rekening Pembayaran:<br>
        Bank BNI
        <ul>
            <li><strong>No Rekening :</strong> 8282823875</li>
            <li><strong>a.n. :</strong> Edukasi Indonesia Jaya</li>
        </ul>
        Wawancara Via: Telepon (di <?php echo e($data['no_wa']); ?>)</p>

    <p><b><u>DATA PRIBADI</u></b></p>
    <ul>
        <li>Nama: <?php echo e($data['nama_leng']); ?></li>
        <li>Jenis Kelamin: <?php echo e($data['jk']); ?></li>
        <li>Tempat Lahir: <?php echo e($data['tmpt_lahir']); ?></li>
        <li>Tanggal Lahir: <?php echo e($data['tgl_lahir']); ?></li>
        <li>Email: <?php echo e($data['email']); ?></li>
        <li>No HP/WA: <?php echo e($data['no_hp']); ?></li>
    </ul>
    <p>Setelah melakukan pembayaran, konfirmasi dapat dilakukan melalui WA ke: <a
            href="https://api.whatsapp.com/send?phone=6287890198284&text=Halo%20Admin%20Saya%20Sudah%20Daftar%20Online%20di%20<?php echo e($data['kampus']); ?>">6287890198284</a>.
    </p>
</body>

</html>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Biru-Kuning/resources/views/emails/registration.blade.php ENDPATH**/ ?>