<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="INSTITUT TEKNOLOGI BISNIS RIAU  adalah perguruan tinggi berbasis nilai-nilai Islami yang berlokasi di Riau. ITB RIAU menawarkan berbagai program studi unggulan jenjang S1, seperti S1 Bisnis Digital, Teknik Elektro, Sistem dan Teknologi Informasi. Dengan biaya kuliah yang terjangkau, ITB RIAU menjadi pilihan tepat bagi calon mahasiswa yang mencari pendidikan berkualitas, lingkungan akademik yang mendukung, serta pengembangan karakter islami. Dapatkan pengalaman belajar yang modern, relevan dengan kebutuhan dunia kerja, dan bernilai keislaman di ITB RIAU.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, INSTITA, kampus INSTITA , biaya kuliah kampus Institut Elkatarie , biaya kuliah, kelas sabtu, akreditasi Institut Elkatarie, kelas karyawan terjangkau Riau , S1 Bisnis Digital, Teknik Elektro, Sistem dan Teknologi Informasi, kampus murah Di Riau , kampus Di Riau , ITB Riau, biaya kuliah, kelas sabtu, akreditasi ITB RIAU ,
     Kampus Kelas Karyawan Di Riau , Kuliah Sambil Kerja Di Riau , Universitas Terbaik di Riau  untuk Karyawan, Biaya Kuliah Terjangkau di Riau , Universitas Kelas Sabtu Minggu Di Riau , Akreditasi Universitas Di Riau ,Perguruan Tinggi Swasta Murah di Riau,  Kampus Swasta Terbaik Riau , Universitas Murah  Di Riau  terakreditasi Baik,
     Kampus Terjangkau di Riau  untuk Karyawan, , Kuliah dengan Biaya Murah di Riau  , Universitas dengan Kelas Online Riau , Kampus Swasta Kelas Sabtu Minggu di Riau , Biaya Kuliah  Sarjana Murah di Riau , Biaya Kuliah S1 Murah di Riau  , Kampus dengan Program Studi Lengkap di Riau " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <!--ADS GSC-->

    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; INSTITUT TEKNOLOGI BISNIS RIAU  (Kelas Karyawan)</title>
    <meta property="og:title" content="INSTITUT TEKNOLOGI BISNIS RIAU  (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="INSTITUT TEKNOLOGI BISNIS RIAU  (Kelas Karyawan)">
    <meta property="og:image" content="https://itbriau.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="INSTITUT TEKNOLOGI BISNIS RIAU  di Kota Riau menawarkan program S1 Bisnis Digital, Teknik Elektro, Sistem dan Teknologi Informasi dengan biaya kuliah terjangkau. Pilihan tepat untuk pendidikan berkualitas berbasis nilai-nilai Islami.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="INSTITUT TEKNOLOGI BISNIS RIAU  (Kelas Karyawan)">
    <meta name="twitter:description" content="INSTITUT TEKNOLOGI BISNIS RIAU  di Kota Riau menyediakan program Kelas Karyawan dengan biaya kuliah terjangkau untuk jenjang S1 Bisnis Digital, Teknik Elektro, Sistem dan Teknologi Informasi. Dirancang khusus bagi pekerja dan profesional yang ingin melanjutkan pendidikan tanpa mengganggu aktivitas kerja, ITB RIAU menawarkan jadwal fleksibel, suasana akademik islami, serta kurikulum yang relevan dengan kebutuhan dunia kerja. Raih gelar sarjana sambil tetap produktif bersama ITB RIAU Kelas Karyawan!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content="https://itbriau.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="INSTITUT TEKNOLOGI BISNIS RIAU | Kuliah Karyawan (K2)" />
    
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&family=DM+Sans:wght@400;700&display=swap" rel="stylesheet">
    <link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.css" />
    <link href="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.css" rel="stylesheet">

    <style>
        /* FIX TOTAL DOUBLE SCROLLBAR */
        html {
            overflow: -moz-scrollbars-none;
            -ms-overflow-style: none; /* IE and Edge */
            scrollbar-width: none; /* Firefox (untuk menghilangkan scrollbar di level html) */
            height: 100%;
            margin: 0;
            padding: 0;
        }

        html::-webkit-scrollbar {
            display: none; /* Chrome, Safari, Opera */
        }

        body {
            /* Scrollbar hanya boleh ada di sini */
            overflow-y: auto; 
            overflow-x: hidden !important;
            min-height: 100%;
            margin: 0;
            padding: 0;
            position: relative;
            -webkit-overflow-scrolling: touch;
        }

        /* Container utama tidak boleh punya scroll sendiri */
        main {
            overflow: visible !important;
            display: block;
            width: 100%;
        }

        /* Mencegah tombol WA merusak lebar layar */
        .whatsapp-button-container {
            pointer-events: none;
        }
        .whatsapp-button-container a, .whatsapp-button-container div {
            pointer-events: auto;
        }
    </style>

    <?php echo $__env->yieldPushContent('prpend-style'); ?>
    <?php echo $__env->yieldPushContent('addon-style'); ?>
</head>

<body class="antialiased">

    
    <?php echo $__env->make('Frontend.Template.navbar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <main>
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    
    <div class="whatsapp-button-container fixed flex flex-row items-center bottom-4 right-4 z-[9999] md:bottom-10 md:right-10">
        <div style="color:#fff;"
            class="slide-text whatsapp-button hidden md:flex overflow-hidden shadow-2xl transition-all duration-500 ease-in-out bg-[#40C351] h-[45px] items-center px-4 font-poppins text-white rounded-full mr-2">
            <span class="whatsapp-button-text text-sm">ingin bertanya ? yuk di click !</span>
        </div>

        <a href="https://wa.me/6289504586704?text=Halo%20Admin%2C%20saya%20mau%20bertanya" 
            target="_blank" rel="noopener noreferrer" class="hover:scale-110 transition-transform">
            <img src="<?php echo e(asset('images/logo/wa.jpg')); ?>" alt="WhatsApp" class="w-12 h-12 md:w-[70px] md:h-[70px] rounded-full shadow-lg">
        </a>
    </div>

    
    <?php echo $__env->make('Frontend.Template.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/aos@2.3.4/dist/aos.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/swiper@11/swiper-bundle.min.js"></script>
    <script src="<?php echo e(asset('./js/app.js')); ?>"></script>

    <?php echo $__env->yieldPushContent('prpend-script'); ?>
    <?php echo $__env->yieldPushContent('addon-script'); ?>

    <script>
        AOS.init({ once: true });
        // Disable Right Click
        document.addEventListener('contextmenu', function(e) { e.preventDefault(); });
    </script>
</body>
</html><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Biru-Kuning/resources/views/Frontend/Layouts/app.blade.php ENDPATH**/ ?>