<!DOCTYPE html>
<html>

<head>
    <title>Konfirmasi Pendaftaran</title>
</head>

<body>
    <p><b>Kepada Yth Calon Mahasiswa di Tempat,</b></p>
    <p>Terima kasih Anda telah melakukan Pendaftaran Online di situs kami dengan data berikut:</p>
    <p>Nomor Pendaftaran: <b>{{ $data['no_daftar'] }}</b><br>
        Perguruan Tinggi: <b>{{ $data['kampus'] }}</b><br>
        Jurusan: {{ $data['jurusan'] }}<br>
        Informasi Biaya Pendaftaran:
        <ul>
            @if(isset($data['jenjang_tersedia']) && count($data['jenjang_tersedia']) > 0)
                @foreach($data['jenjang_tersedia'] as $jenjang => $biaya)
                    <li><strong>{{ $jenjang }}:</strong> Rp. {{ $biaya }},-</li>
                @endforeach
            @else
                <li><strong>S1:</strong>150.000,-</li>
            @endif
        </ul>
        Rekening Pembayaran:<br>
        Bank BNI
        <ul>
            <li><strong>No Rekening :</strong> 8282823875</li>
            <li><strong>a.n. :</strong> Edukasi Indonesia Jaya</li>
        </ul>
        Wawancara Via: Telepon (di {{ $data['no_wa'] }})</p>

    <p><b><u>DATA PRIBADI</u></b></p>
    <ul>
        <li>Nama: {{ $data['nama_leng'] }}</li>
        <li>Jenis Kelamin: {{ $data['jk'] }}</li>
        <li>Tempat Lahir: {{ $data['tmpt_lahir'] }}</li>
        <li>Tanggal Lahir: {{ $data['tgl_lahir'] }}</li>
        <li>Email: {{ $data['email'] }}</li>
        <li>No HP/WA: {{ $data['no_hp'] }}</li>
    </ul>
    <p>Setelah melakukan pembayaran, konfirmasi dapat dilakukan melalui WA ke: <a
            href="https://api.whatsapp.com/send?phone=6287890198284&text=Halo%20Admin%20Saya%20Sudah%20Daftar%20Online%20di%20{{ $data['kampus'] }}">6287890198284</a>.
    </p>
</body>

</html>
