@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
                SEKAPUR SIRIH MENGENAI ITB RIAU
                Institut Teknologi Bisnis Riau (ITB Riau) <br>dibawah naungan Yayasan At-Thoiba Riau resmi memperoleh izin operasional pendidikan yang diterbitkan oleh Menteri Pendidikan, Kebudayaan, Riset, dan Teknologi Nomor 80/E/O/2022 pada tanggal 17 Februari 2022. Dengan tiga program studi program sarjana (S1), Bisnis Digital, Teknik Elektro dan Sistem Teknologi Informasi dengan diperolehnya izin pendirian perguruan tinggi Institut Teknologi Bisnis Riau resmi menapakkan kaki memulai pengabdian memberikan layanan pendidikan kepada masayarakat dengan profesional.
            <br><br>
            Perjalanan panjang pendirian Institut Teknologi Bisnis Riau dalam memperoleh izin pendidikan telah berjalan selama hampir dua tahun. Banyak hal yang dialami, baik hal-hal yang dihadapi sebagai kendala, hambatan, tantangan dan peluang maupun keberhasilan yang akan membawa Institut Teknologi Bisnis Riau sebagai pelaksana pendidikan swasta taat azaz. Keberlanjutan dan keberhasilan dalam memperolah izin pendidikan tidak lepas dari usaha besar yang penuh lika-liku dari sebuah lembaga pendidikan.
            <br><br>
            Institut Teknologi Bisnis Riau yang lebih dikenal dengan ITB Riau memiliki dua kampus pertama kampus satu berada di Jalan Kapau Sari Ujung, RT.003 RW.010 Tenayan Raya-Kota Pekanbaru, dan kampus dua di jalan SM. Amin No.3-4 Tampan-Kota Pekanbaru, dengan bekal izin pendidikan tersebut secara simultan Institut Teknologi Bisnis Riau berupaya menjadi salah satu Institut Teknologi dan Bisnis berbasis riset atau institusi akademik terkemuka di Provinsi Riau dan Pulau Sumatera pada tahun 2042, sebagai Institut Teknologi Riset upaya-upaya yang dilakukan untuk memperoleh pencapaian tertinggi dalam hal penemuan, pengembangan dan difusi pengetahuan secara regional dan gobal akan selalu dilakukan.
            <br><br>   </p>

            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
