<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Biaya extends Model
{
    protected $table = 'biaya';
    protected $primaryKey = 'biaya_id';
    protected $fillable = [ 'kategori', 'jurusan', 'biaya_awal', 'biaya_spp', 'biaya_sppo', 'deskripsi' ];
    public $timestamps = false; // kalau tidak pakai created_at & updated_at
}